{#- OZI 0.3
# ozi/templates/README.j2
# SPDX-License-Identifier: Unlicense
-#}
{%- if project.long_description_content_type == 'rst' %}
{% include 'README.rst.j2' %}
{%- elif project.long_description_content_type == 'md' %}
{% include 'README.md.j2' %}
{%- elif project.long_description_content_type == 'txt' %}
{% include 'README.txt.j2' %}
{% endif %}