{#- OZI 0.1
# ozi/templates/LICENSE.txt.j2
# SPDX-License-Identifier: Unlicense
-#}
{% set license_template = project.license.split('::')|map('trim')|map('underscorify')|join('/') %}
{% set filename = project.license_expression.split(' ')[0]|lower ~ '.txt'%}
{% set path = ['license', license_template, filename]|join('/') %}
{% include path %}